netapp_ontap.models.ems_event_action API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ems_event_action`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class EmsEventActionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the EmsEventAction object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `confirmation_message: EmsUiMessage GET`

    Information to be displayed to the user.

  `description: EmsUiMessage GET`

    Information to be displayed to the user.

  `href: str GET`

    URI on which to perform the action, using the HTTP method specified in the method property.

    Example: /api/resourcelink

  `method: str GET`

    HTTP verb, such as PATCH, POST, used to perform the action.

    Example: PATCH

  `name: str GET`

    Name of the action.

    Example: schedule

  `parameters: List[EmsActionParameter] GET`

    Parameter list for the action.

  `request_body_template: Dict GET`

    JSON object describing the structure of the request body if arguments must be provided in the body when invoking the action. A JSON string value that takes the form of {parameter-name} must be substituted by user input values encoded as the appropriate JSON type. The following table gives examples where the parameter type is a string, an integer, and an array: | request_body_template value | parameter value | request body | | --------------------------- | ---------------------------- | ------------------------------- | | {"name": "{user-name}"} | user-name="Joe" | {"name": "Joe"} | | {"retry count": "{count}"} | count=10 | {"retry_count": 10} | | {"domains": "{dns-names}"} | dns-names=["dns-1", "dns-2"] | {"domains": ["dns-1", "dns-2"]} | Only JSON string values that start with a '{' and end with a '}' should be considered for parameter substitutions. A JSON string value such as "{user-name} is the syntax" should be treated as a literal string with no parameter substitution to be performed. Double curly braces '{{' and '}}' are used to escape parameter substitutions, therefore double curly braces must be converted to single curly braces. For example, "{{user-name}}" is converted to the JSON string value "{user-name}". Note that this rule only applies if a JSON string starts with '{{' and ends with '}}'. The following table provides examples of when parameter substitutions must not be performed: | request_body_template value | request body | | --------------------------------- | -------------------------------- | | {"name": "{user-name} is bad"} | {"name": "{user-name} is bad"} | | {"name": "{{user-name}}"} | {"name": "{user-name}"} | | {"name": "{{user-name}} is bad"} | {"name": "{{user-name}} is bad"} | | {"name": "{{{{user-name}}}}"} | {"name": "{{user-name}}"} |

  `title: EmsUiMessage GET`

    Information to be displayed to the user.